[Libreoffice-commits] .: solenv/gbuild

2011-10-06 Thread David Tardon
 solenv/gbuild/ExternalLib.mk |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 8cc9bf475a351bd0851f057f38ee596ca9ecc7ce
Author: David Tardon 
Date:   Fri Oct 7 07:05:15 2011 +0200

--strip-component is GNU tar extension

diff --git a/solenv/gbuild/ExternalLib.mk b/solenv/gbuild/ExternalLib.mk
index daec9dc..90763f4 100644
--- a/solenv/gbuild/ExternalLib.mk
+++ b/solenv/gbuild/ExternalLib.mk
@@ -101,7 +101,7 @@ endef
 define gb_ExternalLib__command_autotools
rm -fr $(call gb_ExternalLib_get_workdir,$(1)) && \
mkdir -p $(call gb_ExternalLib_get_builddir,$(1)) && \
-   tar -x -C $(call gb_ExternalLib_get_builddir,$(1)) --strip-component=1 
-f $< && \
+   $(GNUTAR) -x -C $(call gb_ExternalLib_get_builddir,$(1)) 
--strip-component=1 -f $< && \
cd $(call gb_ExternalLib_get_builddir,$(1)) && for p in $(T_PATCHES) ; 
do patch -p 1 < $(gb_REPOS)/$$p || exit 1; done && \
CC="$(gb_CC)" CXX="$(gb_CXX)" CFLAGS="$(T_CFLAGS)" 
CXXFLAGS="$(T_CXXFLAGS)" PKG_CONFIG_PATH="$(PKG_CONFIG_PATH) 
$(OUTDIR)/lib/pkgconfig" ./configure $(if $(findstring 
YES,$(CROSS_COMPILING)),--build=$(BUILD_PLATFORM) --host=$(HOST_PLATFORM)) 
--prefix=$(OUTDIR) $(T_CONF_ARGS) && \
for p in $(T_POST_PATCHES) ; do patch -p 1 < $(gb_REPOS)/$p || exit 1; 
done
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: binfilter/bf_svx binfilter/inc

2011-10-06 Thread Joseph Powers
 binfilter/bf_svx/source/items/svx_numitem.cxx  |   32 ---
 binfilter/bf_svx/source/items/svx_paraitem.cxx |   93 --
 binfilter/bf_svx/source/items/svx_svxfont.cxx  |  142 ---
 binfilter/bf_svx/source/items/svx_textitem.cxx |  228 -
 binfilter/bf_svx/source/items/svx_xmlcnitm.cxx |1 
 binfilter/inc/bf_svtools/xmlcnimp.hxx  |2 
 binfilter/inc/bf_svx/adjitem.hxx   |7 
 binfilter/inc/bf_svx/cmapitem.hxx  |2 
 binfilter/inc/bf_svx/escpitem.hxx  |6 
 binfilter/inc/bf_svx/flstitem.hxx  |6 
 binfilter/inc/bf_svx/langitem.hxx  |2 
 binfilter/inc/bf_svx/lspcitem.hxx  |6 
 binfilter/inc/bf_svx/pgrditem.hxx  |4 
 binfilter/inc/bf_svx/postitem.hxx  |4 
 binfilter/inc/bf_svx/scripttypeitem.hxx|   12 -
 binfilter/inc/bf_svx/svxfont.hxx   |6 
 binfilter/inc/bf_svx/udlnitem.hxx  |2 
 binfilter/inc/bf_svx/wghtitem.hxx  |4 
 binfilter/inc/bf_xmloff/xmlcnitm.hxx   |4 
 19 files changed, 30 insertions(+), 533 deletions(-)

New commits:
commit 8fd4c147c5e2432a646dcfb11980bbb6d628ef92
Author: Joseph Powers 
Date:   Thu Oct 6 21:10:12 2011 -0700

Some DBG_BF_ASSERT cleanup in bf_svx

diff --git a/binfilter/bf_svx/source/items/svx_numitem.cxx 
b/binfilter/bf_svx/source/items/svx_numitem.cxx
index c271397..7a787df 100644
--- a/binfilter/bf_svx/source/items/svx_numitem.cxx
+++ b/binfilter/bf_svx/source/items/svx_numitem.cxx
@@ -298,10 +298,6 @@ sal_Int32 SvxNumberType::nRefCount = 0;
 /*N*/   SetShowSymbol(rFormat.IsShowSymbol());
 /*N*/   sCharStyleName  = rFormat.sCharStyleName;
 /*N*/   DELETEZ(pGraphicBrush);
-/*N*/   if(rFormat.pGraphicBrush)
-/*N*/ {
-/*?*/   DBG_BF_ASSERT(0, "STRIP");
-/*N*/ }
 /*N*/   DELETEZ(pBulletFont);
 /*N*/   if(rFormat.pBulletFont)
 /*N*/   pBulletFont = new Font(*rFormat.pBulletFont);
@@ -350,10 +346,6 @@ sal_Int32 SvxNumberType::nRefCount = 0;
 /*N*/   delete pGraphicBrush;
 /*N*/   pGraphicBrush = 0;
 /*N*/   }
-/*N*/   else if(!pGraphicBrush || (pGraphicBrush && !(*pBrushItem == 
*pGraphicBrush)))
-/*N*/   {
-/*?*/   DBG_BF_ASSERT(0, "STRIP");
-/*N*/}
 /*N*/
 /*N*/   if(pOrient)
 /*N*/   eVertOrient = *pOrient;
@@ -368,8 +360,6 @@ sal_Int32 SvxNumberType::nRefCount = 0;
 
 
 
-
-
 /*N*/ SvxFrameVertOrientSvxNumberFormat::GetVertOrient() const
 /*N*/ {
 /*N*/   return eVertOrient;
@@ -385,12 +375,6 @@ sal_Int32 SvxNumberType::nRefCount = 0;
 
 
 
-
-
-
-
-
-
 /*N*/ String SvxNumberFormat::CreateRomanString( ULONG nNo, BOOL bUpper )
 /*N*/ {
 /*N*/   nNo %= 4000;// mehr kann nicht dargestellt werden
@@ -635,7 +619,6 @@ static SvxNumberFormat* pStdOutlineNumFmt = 0;
 /*N*/   delete aFmts[ i ];
 /*N*/   aFmts[ i ] = new SvxNumberFormat( rNumFmt );
 /*N*/   aFmtsSet[i] = bIsValid;
-/*N*/ //bInvalidRuleFlag = TRUE;
 /*N*/   }
 /*N*/ }
 
@@ -649,20 +632,7 @@ static SvxNumberFormat* pStdOutlineNumFmt = 0;
 /*N*/   for(USHORT i = 0; i < GetLevelCount(); i++)
 /*N*/   {
 /*N*/   SvxNumberFormat aFmt(GetLevel(i));
-/*N*/   const SvxBrushItem* pBrush = aFmt.GetBrush();
-/*N*/   const String* pLinkStr;
-/*N*/   const Graphic* pGraphic;
-/*N*/   if(SVX_NUM_BITMAP == aFmt.GetNumberingType())
-/*N*/   {
-/*N*/   if(pBrush &&
-/*N*/   0 != (pLinkStr = pBrush->GetGraphicLink()) &&
-/*N*/   pLinkStr->Len() &&
-/*N*/   0 !=(pGraphic = pBrush->GetGraphic()))
-/*N*/   {
-/*?*/   DBG_BF_ASSERT(0, "STRIP");
-/*N*/   }
-/*N*/   }
-/*N*/   else if((SVX_NUM_BITMAP|LINK_TOKEN) == aFmt.GetNumberingType())
+/*N*/   if((SVX_NUM_BITMAP|LINK_TOKEN) == aFmt.GetNumberingType())
 /*N*/   aFmt.SetNumberingType(SVX_NUM_BITMAP);
 /*N*/   SetLevel(i, aFmt);
 /*N*/   }
diff --git a/binfilter/bf_svx/source/items/svx_paraitem.cxx 
b/binfilter/bf_svx/source/items/svx_paraitem.cxx
index 6dd3dc9..181a460 100644
--- a/binfilter/bf_svx/source/items/svx_paraitem.cxx
+++ b/binfilter/bf_svx/source/items/svx_paraitem.cxx
@@ -305,33 +305,12 @@ using namespace ::com::sun::star;
 
 // ---
 
-/*?*/ sal_uInt16 SvxLineSpacingItem::GetValueCount() const
-/*?*/ {
-/*?*/   DBG_BF_ASSERT(0, "STRIP"); return SVX_LINESPACE_END;
-/*?*/ }
-
-// ---
-
 /*?*/ XubString SvxLineSpacingItem::GetValueTextByPos( sal_uInt16 /*nPos*/ ) 
const
 /*?*/ {
 /*?*/ DBG_BF_ASSERT(0, "STRIP"); XubString aText;
 /*?*/   return aText;
 /*?*/ }
 
-// ---
-
-/*?*/ sal_uInt16 SvxLineSpacingItem::GetEnumValue() const
-/*?*/ {
-/*?*/ DBG_BF_ASSERT(0, "STRIP"); return 0;
-/*?*/ }
-
-// --

[Libreoffice-commits] .: sc/source

2011-10-06 Thread Takeshi Abe
 sc/source/filter/xml/xmlexprt.cxx |   13 -
 sc/source/filter/xml/xmlimprt.cxx |   14 --
 2 files changed, 27 deletions(-)

New commits:
commit 6b280c938d2213cf9e7ddea13baa38427c3b5c6d
Author: Takeshi Abe 
Date:   Fri Oct 7 00:51:06 2011 +0900

delete NULL is safe

diff --git a/sc/source/filter/xml/xmlexprt.cxx 
b/sc/source/filter/xml/xmlexprt.cxx
index 51ac341..52e35dc 100644
--- a/sc/source/filter/xml/xmlexprt.cxx
+++ b/sc/source/filter/xml/xmlexprt.cxx
@@ -540,31 +540,18 @@ ScXMLExport::ScXMLExport(
 
 ScXMLExport::~ScXMLExport()
 {
-if (pGroupColumns)
 delete pGroupColumns;
-if (pGroupRows)
 delete pGroupRows;
-if (pColumnStyles)
 delete pColumnStyles;
-if (pRowStyles)
 delete pRowStyles;
-if (pCellStyles)
 delete pCellStyles;
-if (pRowFormatRanges)
 delete pRowFormatRanges;
-if (pMergedRangesContainer)
 delete pMergedRangesContainer;
-if (pValidationsContainer)
 delete pValidationsContainer;
-if (pChangeTrackingExportHelper)
 delete pChangeTrackingExportHelper;
-if (pChartListener)
 delete pChartListener;
-if (pCellsItr)
 delete pCellsItr;
-if (pDefaults)
 delete pDefaults;
-if (pNumberFormatAttributesExportHelper)
 delete pNumberFormatAttributesExportHelper;
 }
 
diff --git a/sc/source/filter/xml/xmlimprt.cxx 
b/sc/source/filter/xml/xmlimprt.cxx
index 3c61a1d..f14b43e 100644
--- a/sc/source/filter/xml/xmlimprt.cxx
+++ b/sc/source/filter/xml/xmlimprt.cxx
@@ -1674,9 +1674,6 @@ ScXMLImport::ScXMLImport(
 sCellStyle(RTL_CONSTASCII_USTRINGPARAM(SC_UNONAME_CELLSTYL)),
 sStandardFormat(RTL_CONSTASCII_USTRINGPARAM(SC_STANDARDFORMAT)),
 sType(RTL_CONSTASCII_USTRINGPARAM(SC_UNONAME_TYPE)),
-//  pScAutoStylePool(new SvXMLAutoStylePoolP),
-//  pParaItemMapper( 0 ),
-//  pI18NMap( new SvI18NMap ),
 pDocElemTokenMap( 0 ),
 pStylesElemTokenMap( 0 ),
 pStylesAttrTokenMap( 0 ),
@@ -1869,27 +1866,16 @@ ScXMLImport::~ScXMLImport() throw()
 delete pDataPilotMemberAttrTokenMap;
 delete pConsolidationAttrTokenMap;
 
-//  if (pScAutoStylePool)
-//  delete pScAutoStylePool;
-if (pChangeTrackingImportHelper)
 delete pChangeTrackingImportHelper;
-if (pNumberFormatAttributesExportHelper)
 delete pNumberFormatAttributesExportHelper;
-if (pStyleNumberFormats)
 delete pStyleNumberFormats;
-if (pStylesImportHelper)
 delete pStylesImportHelper;
 
-if (pSolarMutexGuard)
 delete pSolarMutexGuard;
 
-if (pMyNamedExpressions)
 delete pMyNamedExpressions;
-if (pMyLabelRanges)
 delete pMyLabelRanges;
-if (pValidations)
 delete pValidations;
-if (pDetectiveOpArray)
 delete pDetectiveOpArray;
 }
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sw/source

2011-10-06 Thread Jan Holesovsky
 sw/source/ui/misc/pggrid.cxx |4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

New commits:
commit 11c4ce59cbfcae676583488b8750393c4485220d
Author: Takeshi Abe 
Date:   Thu Oct 6 20:15:19 2011 +0900

fdo#41187 - "Prind grid" possible only when "Display grid" checked

diff --git a/sw/source/ui/misc/pggrid.cxx b/sw/source/ui/misc/pggrid.cxx
index 7d315d8..1507b94 100644
--- a/sw/source/ui/misc/pggrid.cxx
+++ b/sw/source/ui/misc/pggrid.cxx
@@ -518,7 +518,9 @@ IMPL_LINK(SwTextGridPage, GridTypeHdl, RadioButton*, 
pButton)
 
 IMPL_LINK(SwTextGridPage, DisplayGridHdl, CheckBox*, EMPTYARG)
 {
-aPrintCB.Enable(aDisplayCB.IsChecked());
+sal_Bool bChecked = aDisplayCB.IsChecked();
+aPrintCB.Enable(bChecked);
+aPrintCB.Check(bChecked);
 return 0;
 }
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/gtk3' - vcl/inc vcl/unx

2011-10-06 Thread Lucas Baudin
 vcl/inc/unx/gtk/gtkframe.hxx  |6 
 vcl/inc/unx/gtk/gtkgdi.hxx|   10 
 vcl/unx/gtk/window/gtkframe.cxx   |   13 
 vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx |  478 --
 4 files changed, 464 insertions(+), 43 deletions(-)

New commits:
commit 6c82d9489a6e0aa92420e820b778fa7e702032ee
Author: Lucas Baudin 
Date:   Thu Sep 29 19:47:01 2011 +0200

Gtk3 fixes, I tweaked the damage function to debug the rendering (the 
damage are is bigger to see a whole widget), if will need to be removed once we 
will fix that

diff --git a/vcl/inc/unx/gtk/gtkframe.hxx b/vcl/inc/unx/gtk/gtkframe.hxx
index 2be3324..0e3ada1 100644
--- a/vcl/inc/unx/gtk/gtkframe.hxx
+++ b/vcl/inc/unx/gtk/gtkframe.hxx
@@ -181,9 +181,6 @@ class GtkSalFrame : public SalFrame, 
basebmp::BitmapDeviceDamageTracker
 int m_nScreen;
 GtkWidget*  m_pWindow;
 guint   m_nIdleFullScreen;
-#if GTK_CHECK_VERSION(3,0,0)
-basebmp::BitmapDeviceSharedPtr  m_aFrame;
-#endif
 int m_nDuringRender;
 GdkWindow*  m_pForeignParent;
 GdkNativeWindow m_aForeignParentWindow;
@@ -303,6 +300,9 @@ class GtkSalFrame : public SalFrame, 
basebmp::BitmapDeviceDamageTracker
 
 DECL_LINK( ImplDelayedFullScreenHdl, void* );
 public:
+#if GTK_CHECK_VERSION(3,0,0)
+basebmp::BitmapDeviceSharedPtr  m_aFrame;
+#endif
 GtkSalFrame( SalFrame* pParent, sal_uLong nStyle );
 GtkSalFrame( SystemParentData* pSysData );
 
diff --git a/vcl/inc/unx/gtk/gtkgdi.hxx b/vcl/inc/unx/gtk/gtkgdi.hxx
index 1fd2e5e..589a109 100644
--- a/vcl/inc/unx/gtk/gtkgdi.hxx
+++ b/vcl/inc/unx/gtk/gtkgdi.hxx
@@ -51,7 +51,6 @@ public:
long nSrcX, long nSrcY,
long nSrcWidth, long nSrcHeight,
sal_uInt16 /*nFlags*/ );
-void updateSettings( AllSettings& rSettings );
 virtual sal_BooldrawNativeControl( ControlType nType, ControlPart 
nPart,
const Rectangle& rControlRegion,
ControlState nState, const 
ImplControlValue& aValue,
@@ -64,9 +63,18 @@ public:
 const rtl::OUString& 
rCaption,
 Rectangle 
&rNativeBoundingRegion,
 Rectangle 
&rNativeContentRegion );
+void updateSettings( AllSettings& rSettings );
 private:
 GtkWidget   *mpWindow;
 GtkStyleContext *mpButtonStyle;
+GtkStyleContext *mpEntryStyle;
+GtkStyleContext *mpScrollbarStyle;
+GtkStyleContext *mpToolbarStyle;
+GtkStyleContext *mpToolButtonStyle;
+void renderAreaToPix( cairo_t* cr, cairo_rectangle_t* rect );
+void drawStyleContext( GtkStyleContext* style, GtkStateFlags flags,
+const Rectangle& rControlRegion, bool render_background = true );
+void getStyleContext( GtkStyleContext** style, GtkWidget* widget );
 };
 
 #else
diff --git a/vcl/unx/gtk/window/gtkframe.cxx b/vcl/unx/gtk/window/gtkframe.cxx
index 84642a5..8934cb3 100644
--- a/vcl/unx/gtk/window/gtkframe.cxx
+++ b/vcl/unx/gtk/window/gtkframe.cxx
@@ -2997,11 +2997,15 @@ void GtkSalFrame::damaged (const basegfx::B2IRange& 
rDamageRect)
  (int) rDamageRect.getHeight(),
  area );
 #endif
+/* FIXME: this is a dirty hack, to render buttons correctly, we
+ * should of course remove the -100 and + 200, but the whole area
+ * won't be rendered then.
+ */
 gtk_widget_queue_draw_area( m_pWindow,
-rDamageRect.getMinX(),
-rDamageRect.getMinY(),
-rDamageRect.getWidth(),
-rDamageRect.getHeight() );
+rDamageRect.getMinX() - 100,
+rDamageRect.getMinY() - 100,
+rDamageRect.getWidth() + 200,
+rDamageRect.getHeight() + 200 );
 #endif
 }
 
@@ -3132,7 +3136,6 @@ gboolean GtkSalFrame::signalDraw( GtkWidget*, cairo_t 
*cr, gpointer frame )
 struct SalPaintEvent aEvent( rect.x, rect.y, rect.width, rect.height );
 aEvent.mbImmediateUpdate = true;
 pThis->CallCallback( SALEVENT_PAINT, &aEvent );
-
 #if GTK_CHECK_VERSION(3,0,0)
 pThis->renderArea( cr, &rect );
 #endif
diff --git a/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx 
b/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx
index 2dc64fc..6058924 100644
--- a/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx
+++ b/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx
@@ -63,74 +63,484 @@ static void NWConvertVCLStateToGTKState( ControlState 
nVCLState,
 }
 }
 
+
+/**
+ * Draw a GtkStyleContext in the given 

[Libreoffice-commits] .: Branch 'feature/gtk3' - vcl/unx

2011-10-06 Thread Lucas Baudin
 vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit c24ca82c489a4bb07a732e4814dad75448765100
Author: Lucas Baudin 
Date:   Thu Sep 29 19:23:04 2011 +0200

Fix compilation in gtk3salnativewidgets

diff --git a/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx 
b/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx
index ae655dd..2dc64fc 100644
--- a/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx
+++ b/vcl/unx/gtk3/gdi/gtk3salnativewidgets-gtk.cxx
@@ -187,8 +187,8 @@ void GtkSalGraphics::copyArea( long nDestX, long nDestY,
 RegionHandle aHnd = m_aClipRegion.BeginEnumRects();
 while( m_aClipRegion.GetNextEnumRect( aHnd, aClipRect ) )
 {
-cairo_rectangle_int_t aRect = { aClipRect.Left(), aClipRect.Top(),
-aClipRect.Right(), 
aClipRect.Bottom() };
+cairo_rectangle_int_t aRect = { (int)aClipRect.Left(), 
(int)aClipRect.Top(),
+(int)aClipRect.Right(), 
(int)aClipRect.Bottom() };
 cairo_region_union_rectangle( clip_region, &aRect );
 }
 m_aClipRegion.EndEnumRects (aHnd);
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: Branch 'feature/writeable-oletool' - src/ole.py src/oletool.py

2011-10-06 Thread Noel Power
 src/ole.py |   30 --
 src/oletool.py |   29 -
 2 files changed, 40 insertions(+), 19 deletions(-)

New commits:
commit 77e73a40bbaf5273ba775e70026c4494bdfbe30f
Author: Noel Power 
Date:   Thu Oct 6 21:58:13 2011 +0100

fixed lots of brainfarts and added lots of debug

diff --git a/src/ole.py b/src/ole.py
index c67df09..ae22314 100644
--- a/src/ole.py
+++ b/src/ole.py
@@ -92,6 +92,7 @@ class Header(object):
 self.secSizeShort = 64
 
 self.params = params
+self.__SSAT = None
 
 def getSectorSize (self):
 return 2**self.secSize
@@ -277,8 +278,11 @@ class Header(object):
 self.bytes[68:72] = struct.pack( ' -1 ):
 oldChain = theSAT.getSectorIDChain(entryID) 
 theSAT.freeChainEntries( oldChain )
 
+print "** debug self.header.getSSAT().array[0] = 
",self.header.getSSAT().array[0]
 if entry.StreamSize < self.header.minStreamSize:
 print "going to use ssat"
 theSAT = self.header.getSSAT()
@@ -222,15 +225,19 @@ class OleContainer:
 newChain = self.header.getOrAllocateFreeSSATChainEntries( 
newNumChainEntries )
 if (  newNumChainEntries != len(newChain) ):
 raise Exception("no space available")
-entryID = newChain[ 0 ]
 # populate and terminate the chain - #FIXME move to be a common
 # routine
+print "newChain (SSAT) ",  newChain
+for i in xrange(0,len(newChain)):
+print "getSSAT().array[ %d ] = %d"%( newChain[i], 
directory.header.getSSAT().array[ newChain[i] ] )
+entryID = newChain[ 0 ]
 lastIndex =  newChain[ len( newChain ) - 1 ]
-self.header.getSSAT().array[ lastIndex ] = -2
+directory.header.getSSAT().array[ lastIndex ] = -2
 for i in xrange(0,len(newChain) ):
 if i > 0:
-self.header.getSSAT().array[ newChain[ i-1 ] ] = newChain[ 
i ]
-#OMG - the assignment above ( to put in the -2 ) doesn't seem to 
work
+directory.header.getSSAT().array[ newChain[ i - 1 ] ] = 
newChain[ i ]
+for i in xrange(0,len(newChain)):
+print "after pop getSSAT().array[ %d ] = %d"%( newChain[i], 
directory.header.getSSAT().array[ newChain[i] ] )
 #FIXME find out what is wrong, because the assignment of the end of
 #chain ID above doesn't seem to work the line below loops :-/ 
 print "newChain (SSAT) (retrieved)",  theSAT.getSectorIDChain( 
entryID )
@@ -286,8 +293,9 @@ class OleContainer:
 entry.UserFlags =  bytearray(4)
 entry.TimeCreated =  bytearray(8)
 entry.TimeModified =  bytearray(8)
-entry.StreamSectorID = 0
+entry.StreamSectorID = -1
 entry.StreamSize = 0
+entry.StreamLocation = ole.StreamLocation.SSAT 
 
 def deleteEntry(self, directory, node, tree ):
 entry = node.Entry
@@ -366,13 +374,9 @@ class OleContainer:
 lastEntry = directory.entries[ len( directory.entries ) - 1]
 entry = ole.Directory.Entry()
 self.makeEntryEmpty( entry )
+
 directory.entries.append( entry )
 dirID = len( directory.entries) - 1 
-# if the old last entry was empty use that other wise use
-# the new one
-if lastEntry.Type == ole.Directory.Type.Empty:
-dirID = len( directory.entries ) - 2
-entry = lastEntry
 
 entry.Name = childName
 self.insertSiblingInTree ( directory, dirID, entry, directory.entries[ 
root.Entry.DirIDRoot ] ) 
@@ -422,7 +426,6 @@ class OleContainer:
 else:
 #storage
 node = self.__findNodeByHierachicalName( root, dirPath )
-print "adding a new file to %s"%dirPath
 entry = self.insertDirEntry( directory, node, fileLeafName )
 if  storageTestCreate:
 entry.NodeColor = ole.Directory.NodeColor.Black
@@ -430,8 +433,8 @@ class OleContainer:
 else:
 #FIXME how to allocate the NodeColor
 entry.NodeColor = node.Entry.NodeColor
-entry.NodeColor = node.Entry.NodeColor
 entry.Type = directory.Type.UserStream
+
 self.updateEntry( directory, entry, filePath )
 
 self.header.write() 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: 2 commits - scp2/source shell/source solenv/inc

2011-10-06 Thread Stephan Bergmann
 scp2/source/ooo/file_ooo.scp |   14 +++---
 shell/source/cmdmail/cmdmailsuppl.cxx|2 +-
 shell/source/unix/exec/shellexec.cxx |6 +++---
 shell/source/unix/misc/makefile.mk   |2 ++
 shell/source/win32/simplemail/makefile.mk|2 +-
 shell/source/win32/simplemail/smplmailclient.cxx |2 +-
 solenv/inc/unxaigppc.mk  |5 ++---
 solenv/inc/unxgcc.mk |4 ++--
 solenv/inc/unxsoli4.mk   |4 ++--
 solenv/inc/unxsols4.mk   |4 ++--
 solenv/inc/unxsolu4.mk   |4 ++--
 11 files changed, 25 insertions(+), 24 deletions(-)

New commits:
commit d550bc3f450dd2d3aa33398eb31bc1163a181c43
Author: Stephan Bergmann 
Date:   Thu Oct 6 21:29:44 2011 +0200

Undo basis/brand split: move some auxiliary executables from basis to brand.

diff --git a/scp2/source/ooo/file_ooo.scp b/scp2/source/ooo/file_ooo.scp
index d43104d..37e1f9d 100644
--- a/scp2/source/ooo/file_ooo.scp
+++ b/scp2/source/ooo/file_ooo.scp
@@ -139,7 +139,7 @@ End
 
 File gid_File_Bin_Open_Url
 BIN_FILE_BODY;
-Dir = gid_Dir_Program;
+Dir = gid_Brand_Dir_Program;
 Name = "open-url";
 Styles = (PACKED);
 End
@@ -150,28 +150,28 @@ End
 
 File gid_File_Bin_Gnome_Open_Url
 BIN_FILE_BODY;
-Dir = gid_Dir_Program;
+Dir = gid_Brand_Dir_Program;
 Name = "gnome-open-url";
 Styles = (PACKED);
 End
 
 File gid_File_Bin_Gnome_Open_Url_Bin
 BIN_FILE_BODY;
-Dir = gid_Dir_Program;
+Dir = gid_Brand_Dir_Program;
 Name = "gnome-open-url.bin";
 Styles = (PACKED);
 End
 
 File gid_File_Bin_Kde_Open_Url
 BIN_FILE_BODY;
-Dir = gid_Dir_Program;
+Dir = gid_Brand_Dir_Program;
 Name = "kde-open-url";
 Styles = (PACKED);
 End
 
 File gid_File_Bin_Cde_Open_Url
 BIN_FILE_BODY;
-Dir = gid_Dir_Program;
+Dir = gid_Brand_Dir_Program;
 Name = "cde-open-url";
 Styles = (PACKED);
 End
@@ -182,7 +182,7 @@ End
 
 File gid_File_Bin_Uri_Encode
 BIN_FILE_BODY;
-Dir = gid_Dir_Program;
+Dir = gid_Brand_Dir_Program;
 Name = "uri-encode";
 Styles = (PACKED);
 End
@@ -191,7 +191,7 @@ End
 
 File gid_File_Bin_Senddoc
 BIN_FILE_BODY;
-Dir = gid_Dir_Program;
+Dir = gid_Brand_Dir_Program;
   #ifdef UNX
 Name = "senddoc";
 Styles = (PACKED);
diff --git a/shell/source/cmdmail/cmdmailsuppl.cxx 
b/shell/source/cmdmail/cmdmailsuppl.cxx
index ec623c0..548b90c 100644
--- a/shell/source/cmdmail/cmdmailsuppl.cxx
+++ b/shell/source/cmdmail/cmdmailsuppl.cxx
@@ -153,7 +153,7 @@ void SAL_CALL CmdMailSuppl::sendSimpleMailMessage( const 
Reference< XSimpleMailM
 OStringBuffer aBuffer;
 aBuffer.append("\"");
 
-OUString 
aProgramURL(RTL_CONSTASCII_USTRINGPARAM("$OOO_BASE_DIR/program/senddoc"));
+OUString 
aProgramURL(RTL_CONSTASCII_USTRINGPARAM("$BRAND_BASE_DIR/program/senddoc"));
 rtl::Bootstrap::expandMacros(aProgramURL);
 
 OUString aProgram;
diff --git a/shell/source/unix/misc/makefile.mk 
b/shell/source/unix/misc/makefile.mk
index be4660d..3f1b64e 100644
--- a/shell/source/unix/misc/makefile.mk
+++ b/shell/source/unix/misc/makefile.mk
@@ -51,6 +51,7 @@ APP1TARGET = gnome-open-url.bin
 APP1OBJS = \
 $(OBJ)$/gnome-open-url.obj
 APP1LIBS =
+APP1RPATH = BRAND
 .IF "$(OS)"!="FREEBSD" && "$(OS)"!="NETBSD" && "$(OS)"!="OPENBSD" && \
 "$(OS)"!="DRAGONFLY"
 APP1STDLIBS=-ldl
@@ -59,6 +60,7 @@ APP1STDLIBS=-ldl
 APP2TARGET = uri-encode
 APP2OBJS = $(OBJ)$/uri-encode.obj

[Libreoffice-commits] .: 2 commits - default_images/sw sw/source

2011-10-06 Thread Cédric Bosdonnat
 default_images/sw/res/page_break.png |binary
 sw/source/ui/docvw/PageBreakWin.cxx  |   82 ---
 2 files changed, 48 insertions(+), 34 deletions(-)

New commits:
commit 6d508f856fa04952a2a8cc0528c04c0d7e9cf3cf
Author: Cédric Bosdonnat 
Date:   Thu Oct 6 22:26:11 2011 +0200

Page Break: implemented final paint of the indicator and its line length

diff --git a/default_images/sw/res/page_break.png 
b/default_images/sw/res/page_break.png
index c9b7c16..41541cc 100644
Binary files a/default_images/sw/res/page_break.png and 
b/default_images/sw/res/page_break.png differ
diff --git a/sw/source/ui/docvw/PageBreakWin.cxx 
b/sw/source/ui/docvw/PageBreakWin.cxx
index 08425db..5ccb209 100644
--- a/sw/source/ui/docvw/PageBreakWin.cxx
+++ b/sw/source/ui/docvw/PageBreakWin.cxx
@@ -37,6 +37,7 @@
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -53,8 +54,9 @@
 #include 
 #include 
 
-#define BUTTON_SIZE 30
-#define ARROW_WIDTH 20
+#define BUTTON_WIDTH 30
+#define BUTTON_HEIGHT 19
+#define ARROW_WIDTH 9
 
 using namespace basegfx;
 using namespace basegfx::tools;
@@ -65,7 +67,7 @@ namespace
 B2DPolygon lcl_CreatePolygon( B2DRectangle aBounds )
 {
 B2DPolygon aRetval;
-const double nRadius = 4;
+const double nRadius = 1;
 const double nKappa((M_SQRT2 - 1.0) * 4.0 / 3.0);
 
 // Create the top left corner
@@ -204,39 +206,34 @@ void SwPageBreakWin::Paint( const Rectangle& )
 sdr::contact::createBaseProcessor2DFromOutputDevice(
 *this, aNewViewInfos );
 
-pProcessor->process( aSeq );
-
-// Paint the picture
-Image aImg( SW_RES( IMG_PAGE_BREAK ) );
-DrawImage( Point( 3, 3 ), aImg );
-
 // Paint the symbol if not readonly button
 if ( IsEnabled() )
 {
-Point aPicPos( aRect.getWidth() - ARROW_WIDTH, 0 );
-Size aPicSize( ARROW_WIDTH, aRect.getHeight() );
-Rectangle aSymbolRect( aPicPos, aPicSize );
-
-// 10% distance to the left
-const long nBorderDistanceLeft = 
((aSymbolRect.GetWidth()*100)+500)/1000;
-aSymbolRect.Left()+=nBorderDistanceLeft;
-// 40% distance to the right
-const long nBorderDistanceRight = 
((aSymbolRect.GetWidth()*400)+500)/1000;
-aSymbolRect.Right()-=nBorderDistanceRight;
-// 30% distance to the top button border
-const long nBorderDistanceTop = 
((aSymbolRect.GetHeight()*300)+500)/1000;
-aSymbolRect.Top()+=nBorderDistanceTop;
-// 25% distance to the bottom button border
-const long nBorderDistanceBottom = 
((aSymbolRect.GetHeight()*250)+500)/1000;
-aSymbolRect.Bottom()-=nBorderDistanceBottom;
-
-SymbolType nSymbol = SYMBOL_SPIN_DOWN;
-DecorationView aDecoView( this );
-aDecoView.DrawSymbol( aSymbolRect, nSymbol,
-  ( 
Application::GetSettings().GetStyleSettings().GetHighContrastMode()
-? Color( COL_WHITE )
-: Color( COL_BLACK ) ) );
+double nTop = double( aRect.getHeight() ) / 2.0;
+double nBottom = nTop + 4.0;
+double nLeft = aRect.getWidth( ) - ARROW_WIDTH - 6.0;
+double nRight = aRect.getWidth( ) - ARROW_WIDTH + 2.0;
+
+B2DPolygon aTriangle;
+aTriangle.append( B2DPoint( nLeft, nTop ) );
+aTriangle.append( B2DPoint( nRight, nTop ) );
+aTriangle.append( B2DPoint( ( nLeft + nRight ) / 2.0, nBottom ) );
+aTriangle.setClosed( true );
+
+BColor aTriangleColor = Color( COL_BLACK ).getBColor( );
+if ( 
Application::GetSettings().GetStyleSettings().GetHighContrastMode() )
+aTriangleColor = Color( COL_WHITE ).getBColor( );
+
+aSeq.realloc( aSeq.getLength() + 1 );
+aSeq[ aSeq.getLength() - 1 ] = Primitive2DReference( new 
PolyPolygonColorPrimitive2D(
+   B2DPolyPolygon( aTriangle ), aTriangleColor ) );
 }
+
+pProcessor->process( aSeq );
+
+// Paint the picture
+Image aImg( SW_RES( IMG_PAGE_BREAK ) );
+DrawImage( Point( 3, 1 ), aImg );
 }
 
 void SwPageBreakWin::Select( )
@@ -312,7 +309,7 @@ void SwPageBreakWin::UpdatePosition( )
 if ( aFrmRect.Top() == aPrevFrmRect.Top() )
 nYLineOffset = ( aBoundRect.Top() + aFrmRect.Top() ) / 2;
 
-Size aBtnSize( BUTTON_SIZE + ARROW_WIDTH, BUTTON_SIZE );
+Size aBtnSize( BUTTON_WIDTH + ARROW_WIDTH, BUTTON_HEIGHT );
 Point aBtnPos( aFrmRect.Left() - aBtnSize.Width() + ARROW_WIDTH / 2,
 nYLineOffset - aBtnSize.Height() / 2 );
 
@@ -320,7 +317,11 @@ void SwPageBreakWin::UpdatePosition( )
 
 // Update the line position
 Point aLinePos( aFrmRect.Left() + ARROW_WIDTH / 2, nYLineOffset );
-Size aLineSize( aBoundRect.getWidth(), 1 );
+unsigned long nSidebarWidth = 0;
+const SwPostItMgr* pPostItMngr = 
GetEditWin()->GetView().GetWrtShell().GetPostItMgr();
+if ( pPostItMngr && pPostItMn

[Libreoffice-commits] .: cui/source svtools/inc sw/source

2011-10-06 Thread Michael Meeks
 cui/source/tabpages/page.cxx  |   11 ++-
 svtools/inc/svtools/htmlcfg.hxx   |1 -
 sw/source/filter/html/wrthtml.cxx |7 ++-
 sw/source/ui/shells/textsh.cxx|5 +
 4 files changed, 5 insertions(+), 19 deletions(-)

New commits:
commit 77cb41a734c507722c652d0a675ccbf18e3d6b99
Author: Harri Pitkänen 
Date:   Thu Oct 6 20:58:11 2011 +0300

Remove code related to previously disabled HTML 3.2 export

diff --git a/cui/source/tabpages/page.cxx b/cui/source/tabpages/page.cxx
index 59977eb..fe0af32 100644
--- a/cui/source/tabpages/page.cxx
+++ b/cui/source/tabpages/page.cxx
@@ -89,9 +89,6 @@ public:
 /** Returns the HTML export mode, as read from the configuration. */
 inline sal_Int32GetExportMode() const { return mnExpMode; }
 
-/** Returns true, if the current HTML export mode is set to HTML 3.2. */
-inline bool IsExportModeHTML32() const { return mnExpMode 
== 0; } // 0 == HTML_CFG_HTML32, see offmgr/htmlcfg.hxx
-
 virtual voidCommit();
 virtual void Notify( const com::sun::star::uno::Sequence< rtl::OUString >& 
_rPropertyNames);
 
@@ -310,10 +307,6 @@ SvxPageDescPage::SvxPageDescPage( Window* pParent, const 
SfxItemSet& rAttr ) :
 0 != (pItem = pShell->GetItem(SID_HTML_MODE
 bWeb = 0 != (((const SfxUInt16Item*)pItem)->GetValue() & HTMLMODE_ON);
 
-// #109989# get the HTML export setting from configuration.
-// !! This is a hack, see comments in SvxHtmlExportModeConfigItem_Impl 
class above.
-bool bHTML32 = SvxHtmlExportModeConfigItem_Impl().IsExportModeHTML32();
-
 //  fill text flow listbox with valid entries
 aTextFlowBox.InsertEntryValue( CUI_RESSTR( RID_SVXSTR_PAGEDIR_LTR_HORI ), 
FRMDIR_HORI_LEFT_TOP );
 if( bCTL )
@@ -328,8 +321,8 @@ SvxPageDescPage::SvxPageDescPage( Window* pParent, const 
SfxItemSet& rAttr ) :
 }
 }
 
-// #109989# show the text direction box in Writer/Web too, but only, if 
HTML export mode is not HTML3.2.
-if( !(bWeb && bHTML32) && (bCJK || bCTL) &&
+// #109989# show the text direction box in Writer/Web too
+if( (bCJK || bCTL) &&
 SFX_ITEM_UNKNOWN < rAttr.GetItemState(GetWhich( 
SID_ATTR_FRAMEDIRECTION )))
 {
 aTextFlowLbl.Show();
diff --git a/svtools/inc/svtools/htmlcfg.hxx b/svtools/inc/svtools/htmlcfg.hxx
index e73a385..9b35b7b 100644
--- a/svtools/inc/svtools/htmlcfg.hxx
+++ b/svtools/inc/svtools/htmlcfg.hxx
@@ -38,7 +38,6 @@
 
 // !!!be aware!!!: the following defines are _not_ used as values in the 
configuration file
 //  this is because of compatibility reasons
-#define HTML_CFG_HTML32 0   // Html 3.2
 #define HTML_CFG_MSIE   1   // Internet Explorer
 #define HTML_CFG_WRITER 2   // Writer
 #define HTML_CFG_NS40   3   // Netscape 4.0
diff --git a/sw/source/filter/html/wrthtml.cxx 
b/sw/source/filter/html/wrthtml.cxx
index ff3c73b..96c4401 100644
--- a/sw/source/filter/html/wrthtml.cxx
+++ b/sw/source/filter/html/wrthtml.cxx
@@ -162,8 +162,7 @@ sal_uLong SwHTMLWriter::WriteStream()
 if( HTML_CFG_NS40==nExportMode )
 nHTMLMode |= HTMLMODE_BORDER_NONE;
 
-if( HTML_CFG_HTML32!=nExportMode )
-nHTMLMode |= HTMLMODE_FONT_GENERIC;
+nHTMLMode |= HTMLMODE_FONT_GENERIC;
 
 if( HTML_CFG_NS40==nExportMode )
 nHTMLMode |= HTMLMODE_NO_CONTROL_CENTERING;
@@ -906,9 +905,7 @@ const SwPageDesc *SwHTMLWriter::MakeHeader( sal_uInt16 
&rHeaderAttrs )
 {
 rtl::OStringBuffer sOut;
 sOut.append(OOO_STRING_SVTOOLS_HTML_doctype).append(' ')
-.append(HTML_CFG_HTML32==nExportMode ?
-OOO_STRING_SVTOOLS_HTML_doctype32 :
-OOO_STRING_SVTOOLS_HTML_doctype40);
+.append(OOO_STRING_SVTOOLS_HTML_doctype40);
 HTMLOutFuncs::Out_AsciiTag( Strm(), sOut.makeStringAndClear().getStr() );
 
 // baue den Vorspann
diff --git a/sw/source/ui/shells/textsh.cxx b/sw/source/ui/shells/textsh.cxx
index e46d7d3..5835e5c 100644
--- a/sw/source/ui/shells/textsh.cxx
+++ b/sw/source/ui/shells/textsh.cxx
@@ -515,10 +515,7 @@ void SwTextShell::ExecInsert(SfxRequest &rReq)
 {
 SvxHtmlOptions& rHtmlOpt = SvxHtmlOptions::Get();
 sal_uInt16 nExport = rHtmlOpt.GetExportMode();
-if( HTML_CFG_MSIE == nExport ||
-HTML_CFG_HTML32 == nExport ||
-HTML_CFG_MSIE == nExport ||
-HTML_CFG_HTML32 == nExport )
+if( HTML_CFG_MSIE == nExport )
 {
 bSingleCol = sal_True;
 }
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sc/source

2011-10-06 Thread Kohei Yoshida
 sc/source/core/data/dociter.cxx |3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

New commits:
commit 0e600dd2805f9284b01a1030f0ad1b720acdaeae
Author: Caolán McNamara 
Date:   Thu Oct 6 12:01:31 2011 -0400

VALGRIND=memcheck => sc unit test discovered bug.

diff --git a/sc/source/core/data/dociter.cxx b/sc/source/core/data/dociter.cxx
index 76a254f..bc9689b 100644
--- a/sc/source/core/data/dociter.cxx
+++ b/sc/source/core/data/dociter.cxx
@@ -517,7 +517,8 @@ SCSIZE 
ScDBQueryDataIterator::SearchColEntryIndex(ScDocument& rDoc, SCTAB nTab,
 ScDBQueryDataIterator::DataAccessInternal::DataAccessInternal(const 
ScDBQueryDataIterator* pParent, ScDBQueryParamInternal* pParam, ScDocument* 
pDoc) :
 DataAccess(pParent),
 mpParam(pParam),
-mpDoc(pDoc)
+mpDoc(pDoc),
+bCalcAsShown( pDoc->GetDocOptions().IsCalcAsShown() )
 {
 nCol = mpParam->mnField;
 nRow = mpParam->nRow1;
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: bug/bug bug/bug.xhtml bug/README.txt

2011-10-06 Thread Loic Dachary
 bug/README.txt |   13 -
 bug/bug.xhtml  |   75 +-
 bug/bug/bug.css|   46 ++
 bug/bug/bug.js |   91 ++--
 bug/bug/jquery.iframe-post-form.js |   92 -
 bug/bug/skin.js|2 
 bug/bug/test.html  |   48 ---
 bug/bug/test.js|   72 
 dev/null   |binary
 9 files changed, 148 insertions(+), 291 deletions(-)

New commits:
commit 87b189e6715a0b1dd2f8b0ba3cf7097e9b211a59
Author: Loic Dachary 
Date:   Thu Oct 6 17:21:32 2011 +0200

Fixes https://freedesktop.dachary.org/show_bug.cgi?id=41300

The attachment is proposed before submitting the bug report instead of 
after submitting the form. There is only one submission instead of two, which 
is less confusing. Furthermore, the submission is protected against double 
click. The description field is added to the attachment so that it no longer 
claims to be limited to screenshots.

diff --git a/bug/README.txt b/bug/README.txt
index d3536b3..9cd1cc9 100644
--- a/bug/README.txt
+++ b/bug/README.txt
@@ -36,19 +36,6 @@ It contains parts:
  * Date: Thu Jun 30 14:16:56 2011 -0400
  */
 
-/**
- * jQuery plugin for posting form including file inputs.
- * 
- * Copyright (c) 2010 - 2011 Ewen Elder
- *
- * Licensed under the MIT and GPL licenses:
- * http://www.opensource.org/licenses/mit-license.php
- * http://www.gnu.org/licenses/gpl.html
- *
- * @author: Ewen Elder  
- * @version: 1.1.1 (2011-07-29)
-**/
-
 /*
  * QUnit - A JavaScript Unit Testing Framework
  * 
diff --git a/bug/bug.xhtml b/bug/bug.xhtml
index fae7c4e..add05de 100644
--- a/bug/bug.xhtml
+++ b/bug/bug.xhtml
@@ -28,7 +28,6 @@
 Bug Submission Assistant
 
 
-
 
 
 
@@ -70,7 +69,6 @@
 4Version
 5Description
 6Submit
-7Attach
   
   
 http://wiki.documentfoundation.org/Bug_Submission_Assistant";>Bug 
Submission Assistant is copyright (C) 2011 Loic Dachary published under http://www.gnu.org/licenses/gpl.txt";>GNU GPLv3+. 
Download the sources with git clone http://cgit.freedesktop.org/libreoffice/website";>http://cgit.freedesktop.org/libreoffice/website.
@@ -162,10 +160,49 @@ Expected behavior:
   
 
 
-
- Submit
-  
-   
+
+
+
+  
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+  
+  
+Optionally attach a document or a 
screenshot. 
+
+
+ 
+ 
+   
+   Browse
+ 
+
+  
+  
+Explain what is attached:
+
+  
+
+
+ 
+
+  
+  
+
+  
+
 

  Related bug reports
@@ -183,32 +220,6 @@ Expected behavior:
 You can edit it or add attachments using the 
corresponding bugzilla page.
   
 
-  
-
-  If you have a screenshot illustrating the problem, you can 
upload it here.
-
-   
- 
- 
- 
- 
- 
-  
-
- 
- 
-   
-   Browse
- 
-
-
- 
-
-  
-   
-   
- 
-
 
   
 
diff --git a/bug/bug/bug.css b/bug/bug/bug.css
index 07304ff..7440fc6 100644
--- a/bug/bug/bug.css
+++ b/bug/bug/bug.css
@@ -405,11 +405,16 @@ body {
 }
 
 /* state_submit */
+#submissionoutput {
+display: none;
+}
+
 .state_submit {
 display: none;
 }
 
-.state_submit .go {
+.state_submit input[type='submit'] {
+border: 0;
 margin-left: auto;
 margin-right: 40px;
 background: url('images/submit.png') no-repeat;
@@ -463,7 +468,6 @@ body {
 /* state_attach */
 .state_attach {
 display: none;
-text-align: center;
 }
 
 .state_attach .attach-invite {
@@ -471,42 +475,20 @@ body {
 padding: 10px;
 }
 
-.state_attach .attach-file-and-submit {
-text-align: right;
-vertical-align: top;
-width: 79%;
-}
-
 .state_attach .attach-file-style > div {
 display: inline-block;
 }
 
-.state_attach .attach-submit input {
-background: url('

[Libreoffice-commits] .: l10ntools/scripts

2011-10-06 Thread Miklos Vajna
 l10ntools/scripts/po2lo |   11 ---
 1 file changed, 8 insertions(+), 3 deletions(-)

New commits:
commit 551a13f54e3e0f69d243b50db4f1b442ecce059a
Author: Miklos Vajna 
Date:   Thu Oct 6 16:31:41 2011 +0200

Give better error message on invalid sdf input

diff --git a/l10ntools/scripts/po2lo b/l10ntools/scripts/po2lo
index 969f3ea..a815739 100755
--- a/l10ntools/scripts/po2lo
+++ b/l10ntools/scripts/po2lo
@@ -52,9 +52,14 @@ class Entry:
 self.keys = []
 # 10..13 are translation types
 for idx in range(10, 14):
-if len(self.items[idx]):
-t = {10:'text', 12:'quickhelptext', 13:'title'}[idx]
-self.keys.append((idx, self.sdf2po("%s#%s.%s%s" % (path[-1], 
self.items[4], prefix, t
+try:
+if len(self.items[idx]):
+t = {10:'text', 12:'quickhelptext', 13:'title'}[idx]
+self.keys.append((idx, self.sdf2po("%s#%s.%s%s" % 
(path[-1], self.items[4], prefix, t
+except IndexError:
+print("Tried to access field #%d in sdf file, but no such 
column! Broken sdf file?" % idx)
+print("Fields: %s" % self.items)
+sys.exit(1)
 
 def translate(self, translations):
 """Translates text in the entry based on translations."""
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: unusedcode.easy

2011-10-06 Thread Caolán McNamara
 unusedcode.easy |   17 +
 1 file changed, 17 insertions(+)

New commits:
commit ea4e833c37892b7cf8154244662f8437facaad98
Author: Caolán McNamara 
Date:   Thu Oct 6 15:21:45 2011 +0100

update unused list, note AtomPubSession dtor unused, i.e. probable leak

diff --git a/unusedcode.easy b/unusedcode.easy
index 7680434..535cbf8 100644
--- a/unusedcode.easy
+++ b/unusedcode.easy
@@ -1,6 +1,10 @@
 (anonymous namespace)::Registration::~Registration()
 (anonymous namespace)::getState(std::vector > const&)
 (anonymous 
namespace)::writeInfo(com::sun::star::uno::Reference
 const&, rtl::OUString const&, rtl::OUString const&)
+AtomDocument::AtomDocument(AtomPubSession*, std::basic_string, std::allocator >)
+AtomFolder::AtomFolder(AtomPubSession*, std::basic_string, std::allocator >)
+AtomPubSession::getCollectionUrl(Collection::Type)
+AtomPubSession::~AtomPubSession()
 BitmapPalette::IsGreyPalette() const
 BufferNode::childAt(int) const
 ByteString::Assign(char const*, unsigned short)
@@ -488,6 +492,7 @@ ScDocument::IsLoadingMedium() const
 ScDocument::ValidNewTabName(std::vector > 
const&) const
 ScExternalRefManager::setCacheTableReferencedPermanently(unsigned short, 
rtl::OUString const&, unsigned long)
 
ScFilterDetect::impl_createFactory(com::sun::star::uno::Reference
 const&)
+ScFiltersTest::testVba()
 ScFormulaCell::ScFormulaCell()
 ScGridWindow::InvertSimple(short, int, short, int, unsigned char, unsigned 
char)
 ScHTMLColOffset::Insert(ScHTMLColOffset const*, unsigned short, unsigned short)
@@ -1981,6 +1986,17 @@ binfilter::_ZSortFlys::Remove(binfilter::_ZSortFly 
const&, unsigned short)
 binfilter::_ZSortFlys_SAR::Replace(binfilter::_ZSortFly const&, unsigned short)
 binfilter::_ZSortFlys_SAR::Replace(binfilter::_ZSortFly const*, unsigned 
short, unsigned short)
 binfilter::_ZSortFlys_SAR::_ForEach(unsigned short, unsigned short, unsigned 
char (*)(binfilter::_ZSortFly const&, void*), void*)
+boost::date_time::nth_as_str(int)
+boost::gregorian::create_facet_def(char)
+boost::gregorian::create_facet_def(wchar_t)
+boost::gregorian::generate_locale(std::locale&, char)
+boost::gregorian::generate_locale(std::locale&, wchar_t)
+boost::gregorian::greg_month::get_month_map_ptr()
+boost::gregorian::greg_weekday::as_long_string() const
+boost::gregorian::greg_weekday::as_long_wstring() const
+boost::gregorian::greg_weekday::as_short_string() const
+boost::gregorian::greg_weekday::as_short_wstring() const
+boost::gregorian::special_value_from_string(std::basic_string, std::allocator > const&)
 cairocanvas::CanvasHelper::flush() const
 cairocanvas::CanvasHelper::getPalette()
 cairocanvas::SpriteDeviceHelper::getSurface()
@@ -2405,6 +2421,7 @@ 
layoutimpl::VCLXTabControl::AddChild(com::sun::star::uno::Reference)
 
layoutimpl::prophlp::getProperty(com::sun::star::uno::Reference
 const&, rtl::OUString const&)
+libcmis::SessionFactory::getRepositories(std::map, std::allocator >, std::less, 
std::allocator, std::allocator > > > >)
 libvisio::VSDXCharacterList::getElement(unsigned int)
 libvisio::VSDXOutputElementList::addEllipse(WPXPropertyList const&)
 libvisio::VSDXOutputElementList::addEndLayer()
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: libcmis/prj

2011-10-06 Thread Fridrich Strba
 libcmis/prj/build.lst |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 696f4b98d05aee3fb245ccb97fdb1c50080bf0af
Author: Fridrich Å trba 
Date:   Thu Oct 6 16:10:11 2011 +0200

Fix dependencies of libcmis

diff --git a/libcmis/prj/build.lst b/libcmis/prj/build.lst
index c2beeeb..68de49e 100644
--- a/libcmis/prj/build.lst
+++ b/libcmis/prj/build.lst
@@ -1,3 +1,3 @@
-lc libcmis  :   BOOST:boost soltools NULL
+lc libcmis  :   BOOST:boost CURL:curl LIBXML2:libxml2 soltools NULL
 lc libcmis  usr1-   all lc_mkout NULL
 lc libcmis  nmake   -   all lc_libcmis NULL
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: distro-configs/LibreOfficeAndroid.conf

2011-10-06 Thread Thorsten Behrens
 distro-configs/LibreOfficeAndroid.conf |1 -
 1 file changed, 1 deletion(-)

New commits:
commit d8541ddba4ff38d4c8c8e33b192b8c28e734c987
Author: Thorsten Behrens 
Date:   Thu Oct 6 16:03:54 2011 +0200

cmis disable got removed from configure

diff --git a/distro-configs/LibreOfficeAndroid.conf 
b/distro-configs/LibreOfficeAndroid.conf
index 45befb1..6075646 100644
--- a/distro-configs/LibreOfficeAndroid.conf
+++ b/distro-configs/LibreOfficeAndroid.conf
@@ -18,5 +18,4 @@
 --without-java
 --without-junit
 --without-ppds
---without-cmis
 --without-stlport
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: configure.in

2011-10-06 Thread Fridrich Strba
 configure.in |   33 +
 1 file changed, 13 insertions(+), 20 deletions(-)

New commits:
commit e9ee46c22cbe809fbe5750b81ccce18403f8b69b
Author: Fridrich Å trba 
Date:   Thu Oct 6 15:31:42 2011 +0200

Kill --without-cmis option that is noop anyway

diff --git a/configure.in b/configure.in
index 84ae9d6..d9d28ff 100644
--- a/configure.in
+++ b/configure.in
@@ -522,11 +522,6 @@ AC_ARG_ENABLE(release-build,
 dnl ===
 dnl Optional Packages (--with/without-)
 dnl ===
-AC_ARG_WITH(cmis,
-AS_HELP_STRING([--without-cmis],
-[Disable experimental CMIS interface.]),
-)
-
 AC_ARG_WITH(gnu-patch,
 AS_HELP_STRING([--with-gnu-patch],
 [Specify location of GNU patch on Solaris or FreeBSD.]),
@@ -4627,22 +4622,20 @@ AC_SUBST(VISIO_LIBS)
 dnl ===
 dnl Check for system libcmis
 dnl ===
-if test "x$with_cmis" != "xno" ; then
-AC_MSG_CHECKING([which libcmis to use])
-if test -n "$with_system_libcmis" -o -n "$with_system_libs" && \
-test "$with_system_libcmis" != "no"; then
-AC_MSG_RESULT([external])
-SYSTEM_LIBCMIS=YES
-PKG_CHECK_MODULES( LIBCMIS, libcmis-0.2 )
-else
-AC_MSG_RESULT([internal])
-SYSTEM_LIBCMIS=NO
-BUILD_TYPE="$BUILD_TYPE LIBCMIS"
-fi
-AC_SUBST(SYSTEM_LIBCMIS)
-AC_SUBST(LIBCMIS_CFLAGS)
-AC_SUBST(LIBCMIS_LIBS)
+AC_MSG_CHECKING([which libcmis to use])
+if test -n "$with_system_libcmis" -o -n "$with_system_libs" && \
+test "$with_system_libcmis" != "no"; then
+AC_MSG_RESULT([external])
+SYSTEM_LIBCMIS=YES
+PKG_CHECK_MODULES( LIBCMIS, libcmis-0.2 )
+else
+AC_MSG_RESULT([internal])
+SYSTEM_LIBCMIS=NO
+BUILD_TYPE="$BUILD_TYPE LIBCMIS"
 fi
+AC_SUBST(SYSTEM_LIBCMIS)
+AC_SUBST(LIBCMIS_CFLAGS)
+AC_SUBST(LIBCMIS_LIBS)
 
 
 dnl ===
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: libcmis/makefile.mk

2011-10-06 Thread Fridrich Strba
 libcmis/makefile.mk |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 46da2ed6be6df4089df338098f69375e3e494e44
Author: Fridrich Å trba 
Date:   Thu Oct 6 15:26:18 2011 +0200

System libcmis fix

diff --git a/libcmis/makefile.mk b/libcmis/makefile.mk
index 50a8324..df93424 100644
--- a/libcmis/makefile.mk
+++ b/libcmis/makefile.mk
@@ -36,7 +36,7 @@ TARGET=cmis
 
 # --- Files 
 
-.IF "$(SYSTEM_LIBcmis)" == "YES"
+.IF "$(SYSTEM_LIBCMIS)" == "YES"
 @all:
 @echo "Using system libcmis..."
 .ENDIF
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: oox/Library_oox.mk

2011-10-06 Thread Radek Doulík
 oox/Library_oox.mk |7 ++-
 1 file changed, 6 insertions(+), 1 deletion(-)

New commits:
commit 39160c1044ef2189a76b9c17496f5024312e7458
Author: Radek Doulik 
Date:   Thu Oct 6 15:08:23 2011 +0200

added new source files to the .mk file

diff --git a/oox/Library_oox.mk b/oox/Library_oox.mk
index 8de35c9..52d7dda 100644
--- a/oox/Library_oox.mk
+++ b/oox/Library_oox.mk
@@ -125,7 +125,12 @@ $(eval $(call gb_Library_add_exception_objects,oox,\
 oox/source/drawingml/color \
 oox/source/drawingml/connectorshapecontext \
 oox/source/drawingml/customshapegeometry \
-oox/source/drawingml/customshapepresets \
+oox/source/drawingml/customshapepresets1 \
+oox/source/drawingml/customshapepresets2 \
+oox/source/drawingml/customshapepresets3 \
+oox/source/drawingml/customshapepresets4 \
+oox/source/drawingml/customshapepresets5 \
+oox/source/drawingml/customshapepresets6 \
 oox/source/drawingml/customshapeproperties \
 oox/source/drawingml/diagram/constraintlistcontext \
 oox/source/drawingml/diagram/datamodelcontext \
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: xmlsecurity/source

2011-10-06 Thread Fridrich Strba
 xmlsecurity/source/xmlsec/mscrypt/seinitializer_mscryptimpl.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 4cd6e07a84df42e8fa961f3faef7c316b080ce03
Author: Fridrich Å trba 
Date:   Thu Oct 6 14:53:47 2011 +0200

And yet another .getStr()-style fix

diff --git a/xmlsecurity/source/xmlsec/mscrypt/seinitializer_mscryptimpl.cxx 
b/xmlsecurity/source/xmlsec/mscrypt/seinitializer_mscryptimpl.cxx
index 72063a1..cf1ef2f 100644
--- a/xmlsecurity/source/xmlsec/mscrypt/seinitializer_mscryptimpl.cxx
+++ b/xmlsecurity/source/xmlsec/mscrypt/seinitializer_mscryptimpl.cxx
@@ -67,7 +67,7 @@ cssu::Reference< cssxc::XXMLSecurityContext > SAL_CALL
 //Initialize the crypto engine
 if( sCertDB.getLength() > 0 )
 {
-rtl::OString sCertDir(sCertDB, sCertDB.getLength(), 
RTL_TEXTENCODING_ASCII_US);
+rtl::OString sCertDir(sCertDB.getStr(), sCertDB.getLength(), 
RTL_TEXTENCODING_ASCII_US);
 n_pCertStore = sCertDir.getStr();
 n_hStoreHandle = CertOpenSystemStore( NULL, n_pCertStore ) ;
 if( n_hStoreHandle == NULL )
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: solenv/inc

2011-10-06 Thread Tor Lillqvist
 solenv/inc/wntmsc.mk |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

New commits:
commit c9991493da19151ae9663b8021365b16f0535f0e
Author: Tor Lillqvist 
Date:   Thu Oct 6 15:25:26 2011 +0300

Put .pdb files in misc as before, avoid cluttering up source directories

diff --git a/solenv/inc/wntmsc.mk b/solenv/inc/wntmsc.mk
index 57a7f90..8471135 100644
--- a/solenv/inc/wntmsc.mk
+++ b/solenv/inc/wntmsc.mk
@@ -102,7 +102,7 @@ CFLAGS+= -Gy
 # Flags to enable build with symbols; old comment said "required for crashdump 
feature"
 # but unclear if that is true or not any more; just use the same as 
CFLAGSDEBUG for now.
 # That is what we do in gbuild anyway...
-CFLAGSENABLESYMBOLS=-Zi
+CFLAGSENABLESYMBOLS=-Zi -Fd$(MISC)/$(@:b).pdb
 
 .IF "$(bndchk)" != ""
 .IF "$(debug)" == ""
@@ -149,7 +149,7 @@ CDEFSOBJMT+=-D_DLL
 .ENDIF # "$(DYNAMIC_CRT)"!=""
 
 CFLAGSPROF=-Gh -Fd$(MISC)/$(@:b).pdb
-CFLAGSDEBUG=-Zi
+CFLAGSDEBUG=-Zi -Fd$(MISC)/$(@:b).pdb
 CFLAGSDBGUTIL=
 .IF "$(VC_STANDARD)"==""
 CFLAGSOPT=-Oxs -Oy-
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sw/source

2011-10-06 Thread Cédric Bosdonnat
 sw/source/core/layout/paintfrm.cxx |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit 80d96f738abd01d68befc44a607abe3c360604b1
Author: Cédric Bosdonnat 
Date:   Thu Oct 6 12:43:17 2011 +0200

Page Break: fixed crasher, the page frame can contain no children

diff --git a/sw/source/core/layout/paintfrm.cxx 
b/sw/source/core/layout/paintfrm.cxx
index d51ef08..32a4365 100755
--- a/sw/source/core/layout/paintfrm.cxx
+++ b/sw/source/core/layout/paintfrm.cxx
@@ -3340,7 +3340,7 @@ void SwPageFrm::PaintBreak( ) const
 
 // Test if the first node is a table
 const SwFrm* pFirstFrm = pLayBody->Lower();
-if ( pFirstFrm->IsTabFrm() )
+if ( pFirstFrm && pFirstFrm->IsTabFrm() )
 pFlowFrm = static_cast< const SwTabFrm* >( pFirstFrm );
 
 if ( pFlowFrm && pFlowFrm->IsPageBreak( sal_True ) )
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: 2 commits - accessibility/source avmedia/source

2011-10-06 Thread Tor Lillqvist
 accessibility/source/extended/AccessibleToolPanelDeckTabBar.cxx |2 +-
 accessibility/source/extended/AccessibleToolPanelDeckTabBarItem.cxx |2 +-
 avmedia/source/win/window.cxx   |1 +
 3 files changed, 3 insertions(+), 2 deletions(-)

New commits:
commit 56d6da052e71f6ff374248d8a7dbe92c4ddf7d74
Author: Tor Lillqvist 
Date:   Thu Oct 6 12:51:51 2011 +0300

STRSAFE_NO_DEPRECATE

diff --git a/avmedia/source/win/window.cxx b/avmedia/source/win/window.cxx
index c1b543d..9cc32b9 100644
--- a/avmedia/source/win/window.cxx
+++ b/avmedia/source/win/window.cxx
@@ -33,6 +33,7 @@
 #include 
 #include 
 #include 
+#define STRSAFE_NO_DEPRECATE
 #include 
 #if defined _MSC_VER
 #pragma warning(pop)
commit bdda05135e4e13e417ef480a8ca6171bdbb8a16e
Author: Tor Lillqvist 
Date:   Thu Oct 6 12:18:41 2011 +0300

WaE: class has virtual functions, but destructor is not virtual

diff --git a/accessibility/source/extended/AccessibleToolPanelDeckTabBar.cxx 
b/accessibility/source/extended/AccessibleToolPanelDeckTabBar.cxx
index f4864c9..ec469a2 100644
--- a/accessibility/source/extended/AccessibleToolPanelDeckTabBar.cxx
+++ b/accessibility/source/extended/AccessibleToolPanelDeckTabBar.cxx
@@ -117,7 +117,7 @@ namespace accessibility
 ::svt::IToolPanelDeck& i_rPanelDeck,
 ::svt::PanelTabBar& i_rTabBar
 );
-~AccessibleToolPanelTabBar_Impl();
+virtual ~AccessibleToolPanelTabBar_Impl();
 
 voidcheckDisposed();
 boolisDisposed() const { return m_pPanelDeck == NULL; }
diff --git 
a/accessibility/source/extended/AccessibleToolPanelDeckTabBarItem.cxx 
b/accessibility/source/extended/AccessibleToolPanelDeckTabBarItem.cxx
index b621124..e228017 100644
--- a/accessibility/source/extended/AccessibleToolPanelDeckTabBarItem.cxx
+++ b/accessibility/source/extended/AccessibleToolPanelDeckTabBarItem.cxx
@@ -91,7 +91,7 @@ namespace accessibility
 ::svt::PanelTabBar& i_rTabBar,
 const size_t i_nItemPos
 );
-~AccessibleToolPanelDeckTabBarItem_Impl();
+virtual ~AccessibleToolPanelDeckTabBarItem_Impl();
 
 ::svt::PanelTabBar* getTabBar() const { return m_pTabBar; }
 
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: 2 commits - accessibility/source canvas/source

2011-10-06 Thread Tor Lillqvist
 accessibility/source/extended/AccessibleToolPanelDeck.cxx |2 +-
 canvas/source/cairo/cairo_canvashelper.cxx|2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

New commits:
commit 5cb1597064e81e0ea90d6a000854f9305a45c87a
Author: Tor Lillqvist 
Date:   Thu Oct 6 12:00:07 2011 +0300

WaE: class has virtual functions, but destructor is not virtual

diff --git a/accessibility/source/extended/AccessibleToolPanelDeck.cxx 
b/accessibility/source/extended/AccessibleToolPanelDeck.cxx
index be22454..79088d5 100644
--- a/accessibility/source/extended/AccessibleToolPanelDeck.cxx
+++ b/accessibility/source/extended/AccessibleToolPanelDeck.cxx
@@ -98,7 +98,7 @@ namespace accessibility
 boolisDisposed() const { return m_pPanelDeck == NULL; }
 voiddispose();
 
-~AccessibleToolPanelDeck_Impl();
+virtual ~AccessibleToolPanelDeck_Impl();
 
 Reference< XAccessible >getOwnAccessible() const;
 Reference< XAccessible >getActivePanelAccessible();
commit 6db1788c08b82b0a459d4c480133fa8341ef256f
Author: Tor Lillqvist 
Date:   Thu Oct 6 11:44:44 2011 +0300

WaE: '=' : truncation of constant value

diff --git a/canvas/source/cairo/cairo_canvashelper.cxx 
b/canvas/source/cairo/cairo_canvashelper.cxx
index 0d94db3..7150c46 100644
--- a/canvas/source/cairo/cairo_canvashelper.cxx
+++ b/canvas/source/cairo/cairo_canvashelper.cxx
@@ -1870,7 +1870,7 @@ namespace cairocanvas
 *pColors++ = vcl::unotools::toByteColor(pIn->Blue);
 *pColors++ = vcl::unotools::toByteColor(pIn->Green);
 *pColors++ = vcl::unotools::toByteColor(pIn->Red);
-*pColors++ = 255;
+*pColors++ = -1;
 ++pIn;
 }
 return aRes;
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: oox/source

2011-10-06 Thread Noel Power
 oox/source/ole/olehelper.cxx |   33 +++--
 1 file changed, 31 insertions(+), 2 deletions(-)

New commits:
commit 80b81a561ee92a2abed34f98ee25a0e3c4117326
Author: Noel Power 
Date:   Thu Oct 6 09:53:49 2011 +0100

add hackery re. EditControls, FormattedField & ImageControls from msocximex

diff --git a/oox/source/ole/olehelper.cxx b/oox/source/ole/olehelper.cxx
index fd4672a..1ac4a5d 100644
--- a/oox/source/ole/olehelper.cxx
+++ b/oox/source/ole/olehelper.cxx
@@ -41,6 +41,7 @@
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -78,6 +79,7 @@ using ::com::sun::star::uno::XComponentContext;
 using ::com::sun::star::container::XIndexContainer;
 using ::com::sun::star::container::XNameContainer;
 using ::com::sun::star::lang::XMultiServiceFactory;
+using ::com::sun::star::lang::XServiceInfo;
 
 using namespace ::com::sun::star::form;
 
@@ -138,6 +140,7 @@ struct IdCntrlData
 };
 
 const sal_Int16 TOGGLEBUTTON = -1;
+const sal_Int16 FORMULAFIELD = -2;
 
 typedef std::map< sal_Int16, GUIDCNamePair > GUIDCNamePairMap;
 class classIdToGUIDCNamePairMap
@@ -196,6 +199,9 @@ classIdToGUIDCNamePairMap::classIdToGUIDCNamePairMap()
 {  FormComponentType::PATTERNFIELD,
  { AX_GUID_TEXTBOX, "TextBox"},
 },
+{  FORMULAFIELD,
+ { AX_GUID_TEXTBOX, "TextBox"},
+},
 {  FormComponentType::IMAGEBUTTON,
  { AX_GUID_COMMANDBUTTON, "CommandButton"},
 },
@@ -501,14 +507,37 @@ OleFormCtrlExportHelper::OleFormCtrlExportHelper(  const 
Reference< XComponentCo
 PropertySet aPropSet( mxControlModel );
 if ( aPropSet.getProperty( nClassId, PROP_ClassId ) )
 {
-// psuedo ripped from legacy msocximex
-if ( nClassId == FormComponentType::COMMANDBUTTON )
+/* psuedo ripped from legacy msocximex:
+  "There is a truly horrible thing with EditControls and 
FormattedField
+  Controls, they both pretend to have an EDITBOX ClassId for 
compability
+  reasons, at some stage in the future hopefully there will be a 
proper
+  FormulaField ClassId rather than this piggybacking two controls 
onto the
+  same ClassId, cmc." - when fixed the fake FORMULAFIELD id entry
+  and definition above can be removed/replaced
+*/
+if ( nClassId == FormComponentType::TEXTFIELD)
+{
+Reference< XServiceInfo > xInfo( xCntrlModel,
+UNO_QUERY);
+if (xInfo->
+supportsService( CREATE_OUSTRING( 
"com.sun.star.form.component.FormattedField" ) ) )
+nClassId = FORMULAFIELD;
+}
+else if ( nClassId == FormComponentType::COMMANDBUTTON )
 {
 bool bToggle = false;
 aPropSet.getProperty( bToggle, PROP_Toggle );
 if ( bToggle )
 nClassId = TOGGLEBUTTON;
 }
+else if ( nClassId == FormComponentType::CONTROL )
+{
+Reference< XServiceInfo > xInfo( xCntrlModel,
+UNO_QUERY);
+if (xInfo->
+supportsService(OUString( CREATE_OUSTRING( 
"com.sun.star.form.component.ImageControl" ) ) ) )
+nClassId = FormComponentType::IMAGECONTROL;
+}
 
 GUIDCNamePairMap& cntrlMap = classIdToGUIDCNamePairMap::get();
 GUIDCNamePairMap::iterator it = cntrlMap.find( nClassId );
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: autodoc/inc autodoc/source

2011-10-06 Thread Jan Holesovsky
 autodoc/inc/ary_i/ci_text2.hxx   |2 +-
 autodoc/source/ary_i/kernel/ci_text2.cxx |   12 
 2 files changed, 13 insertions(+), 1 deletion(-)

New commits:
commit 1339a41fb01323d607b5313256f5f9702804b9eb
Author: Jan Holesovsky 
Date:   Thu Oct 6 10:18:13 2011 +0200

Revert "Simplify logic to use std::vector's .empty()"

This reverts commit a6a51b6a69bd14c6ad67a8e6629cf405034dd701.

The commit broke the build, sorry for the push.

diff --git a/autodoc/inc/ary_i/ci_text2.hxx b/autodoc/inc/ary_i/ci_text2.hxx
index eef1d63..8e1c202 100644
--- a/autodoc/inc/ary_i/ci_text2.hxx
+++ b/autodoc/inc/ary_i/ci_text2.hxx
@@ -72,7 +72,7 @@ class DocuTex2
 DYN DocuToken & let_drToken );
 
 const TokenList &   Tokens() const  { return aTokens; }
-boolIsEmpty() const { return aTokens.empty(); }
+boolIsEmpty() const;
 const String &  TextOfFirstToken() const;
 
 String &Access_TextOfFirstToken();
diff --git a/autodoc/source/ary_i/kernel/ci_text2.cxx 
b/autodoc/source/ary_i/kernel/ci_text2.cxx
index 66702af..00a5a7e 100644
--- a/autodoc/source/ary_i/kernel/ci_text2.cxx
+++ b/autodoc/source/ary_i/kernel/ci_text2.cxx
@@ -76,6 +76,18 @@ DocuTex2::AddToken( DYN DocuToken & let_drToken )
 }
 aTokens.push_back(&let_drToken);
 }
+
+bool
+DocuTex2::IsEmpty() const
+{
+for ( ary::inf::DocuTex2::TokenList::const_iterator
+iter = aTokens.begin();
+  iter != aTokens.end();
+)
+{
+return false;
+}
+return true;
 }
 
 using csi::dsapi::DT_TextToken;
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: 4 commits - sfx2/source

2011-10-06 Thread Tor Lillqvist
 sfx2/source/appl/shutdownicon.cxx  |5 +
 sfx2/source/bastyp/fltlst.hxx  |2 +-
 sfx2/source/dialog/taskpane.cxx|2 +-
 sfx2/source/doc/docundomanager.cxx |6 +-
 4 files changed, 12 insertions(+), 3 deletions(-)

New commits:
commit e6b5c5345f25c8881f0dca33d4a7bd4262d5e01e
Author: Tor Lillqvist 
Date:   Thu Oct 6 11:05:26 2011 +0300

WaE: class has virtual functions, but destructor is not virtual

diff --git a/sfx2/source/doc/docundomanager.cxx 
b/sfx2/source/doc/docundomanager.cxx
index 3ae7238..0f42b9d 100644
--- a/sfx2/source/doc/docundomanager.cxx
+++ b/sfx2/source/doc/docundomanager.cxx
@@ -103,6 +103,10 @@ namespace sfx2
 {
 }
 
+virtual ~DocumentUndoManager_Impl()
+{
+};
+
 const SfxObjectShell* getObjectShell() const { return 
rAntiImpl.getBaseModel().GetObjectShell(); }
   SfxObjectShell* getObjectShell()   { return 
rAntiImpl.getBaseModel().GetObjectShell(); }
 
@@ -206,7 +210,7 @@ namespace sfx2
 {
 }
 
-~UndoManagerGuard()
+virtual ~UndoManagerGuard()
 {
 }
 
commit f3cf2a1901e0c7559b8749d94a5865e3508be664
Author: Tor Lillqvist 
Date:   Thu Oct 6 10:54:10 2011 +0300

WaE: class has virtual functions, but destructor is not virtual

diff --git a/sfx2/source/dialog/taskpane.cxx b/sfx2/source/dialog/taskpane.cxx
index 673b562..3204dc6 100644
--- a/sfx2/source/dialog/taskpane.cxx
+++ b/sfx2/source/dialog/taskpane.cxx
@@ -872,7 +872,7 @@ namespace sfx2
 ModuleTaskPane& i_rTaskPane,
 TitledDockingWindow& i_rDockingWindow
 );
-~TaskPaneController_Impl();
+virtual ~TaskPaneController_Impl();
 
 voidSetDefaultTitle( const String& i_rTitle );
 voidActivateToolPanel( const ::rtl::OUString& i_rPanelURL );
commit 3120dc697c721b9823bbabf113eeb8b28f288269
Author: Tor Lillqvist 
Date:   Thu Oct 6 10:45:07 2011 +0300

WaE: class has virtual functions, but destructor is not virtual

diff --git a/sfx2/source/bastyp/fltlst.hxx b/sfx2/source/bastyp/fltlst.hxx
index e7d010b..b0c362e 100644
--- a/sfx2/source/bastyp/fltlst.hxx
+++ b/sfx2/source/bastyp/fltlst.hxx
@@ -50,7 +50,7 @@ class SfxFilterListener
 
 public:
 SfxFilterListener();
-~SfxFilterListener();
+virtual ~SfxFilterListener();
 
 public:
 // XRefreshListener
commit 18a203e7e9e99c4577e46b08219a238ce1fe0e99
Author: Tor Lillqvist 
Date:   Thu Oct 6 10:35:53 2011 +0300

WaE: unreachable code

diff --git a/sfx2/source/appl/shutdownicon.cxx 
b/sfx2/source/appl/shutdownicon.cxx
index 32610f1..82c1af7 100644
--- a/sfx2/source/appl/shutdownicon.cxx
+++ b/sfx2/source/appl/shutdownicon.cxx
@@ -179,6 +179,10 @@ bool ShutdownIcon::LoadModule( osl::Module **pModule,
 }
 #  endif // UNX
 #endif // ENABLE_QUICKSTART_APPLET
+
+#if !defined( ENABLE_QUICKSTART_APPLET ) || defined( UNX )
+// Avoid unreachable code. In the ENABLE_QUICKSTART_APPLET && !UNX
+// case, we have already returned.
 if ( pModule )
 {
 if ( !*pInit )
@@ -188,6 +192,7 @@ bool ShutdownIcon::LoadModule( osl::Module **pModule,
 }
 
 return true;
+#endif // !ENABLE_QUICKSTART_APPLET || UNX
 }
 
 // These two timeouts are necessary to avoid there being
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: autodoc/inc autodoc/source

2011-10-06 Thread Jan Holesovsky
 autodoc/inc/ary_i/ci_text2.hxx   |2 +-
 autodoc/source/ary_i/kernel/ci_text2.cxx |   12 
 2 files changed, 1 insertion(+), 13 deletions(-)

New commits:
commit a6a51b6a69bd14c6ad67a8e6629cf405034dd701
Author: Kevin Hunter 
Date:   Tue Oct 4 18:56:18 2011 -0400

Simplify logic to use std::vector's .empty()

No need to muck about with iterators, adding a loop, and 2 function
calls to test for empty: it's a std::vector under the hood, so use
.empty(), and inline it.

diff --git a/autodoc/inc/ary_i/ci_text2.hxx b/autodoc/inc/ary_i/ci_text2.hxx
index 8e1c202..eef1d63 100644
--- a/autodoc/inc/ary_i/ci_text2.hxx
+++ b/autodoc/inc/ary_i/ci_text2.hxx
@@ -72,7 +72,7 @@ class DocuTex2
 DYN DocuToken & let_drToken );
 
 const TokenList &   Tokens() const  { return aTokens; }
-boolIsEmpty() const;
+boolIsEmpty() const { return aTokens.empty(); }
 const String &  TextOfFirstToken() const;
 
 String &Access_TextOfFirstToken();
diff --git a/autodoc/source/ary_i/kernel/ci_text2.cxx 
b/autodoc/source/ary_i/kernel/ci_text2.cxx
index 00a5a7e..66702af 100644
--- a/autodoc/source/ary_i/kernel/ci_text2.cxx
+++ b/autodoc/source/ary_i/kernel/ci_text2.cxx
@@ -76,18 +76,6 @@ DocuTex2::AddToken( DYN DocuToken & let_drToken )
 }
 aTokens.push_back(&let_drToken);
 }
-
-bool
-DocuTex2::IsEmpty() const
-{
-for ( ary::inf::DocuTex2::TokenList::const_iterator
-iter = aTokens.begin();
-  iter != aTokens.end();
-)
-{
-return false;
-}
-return true;
 }
 
 using csi::dsapi::DT_TextToken;
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-commits] .: sw/inc sw/source

2011-10-06 Thread Stephan Bergmann
 sw/inc/init.hxx|   24 -
 sw/inc/shellio.hxx |3 --
 sw/inc/swdll.hxx   |4 ++
 sw/source/filter/basflt/fltini.cxx |   50 -
 sw/source/ui/app/swdll.cxx |   15 +--
 sw/source/ui/app/swdllimpl.hxx |   14 +-
 6 files changed, 80 insertions(+), 30 deletions(-)

New commits:
commit 06fdd1585d59b2580e8e35bba8a3295bbda28c6e
Author: Stephan Bergmann 
Date:   Thu Oct 6 09:28:20 2011 +0200

Ensure msword lib has not yet been unloaded when aReaderWriter pReaders are 
destroyed.

...as some may use code exported from msword lib.  The newly introduced 
sw::Filters
class can still be improved, bundling what is currently exported through 
various channels
from fltini.cxx.  Also, the code is still not thread safe.

diff --git a/sw/inc/init.hxx b/sw/inc/init.hxx
index 42f5406..daad12c 100644
--- a/sw/inc/init.hxx
+++ b/sw/inc/init.hxx
@@ -28,13 +28,33 @@
 #ifndef _INIT_HXX
 #define _INIT_HXX
 
+#include "sal/config.h"
+
+#include "boost/noncopyable.hpp"
+#include "osl/module.h"
+#include "osl/module.hxx"
+
 class ViewShell;
 
 void _InitCore();   // bastyp/init.cxx
 void _FinitCore();
 
-void _InitFilter(); // basflt/fltini.cxx
-void _FinitFilter();
+namespace sw {
+
+// basflt/fltini.cxx
+class Filters: private boost::noncopyable {
+public:
+Filters();
+
+~Filters();
+
+oslGenericFunction GetMswordLibSymbol( const char *pSymbol );
+
+private:
+osl::Module msword_;
+};
+
+}
 
 // layout/newfrm.cxx
 void _FrmInit();
diff --git a/sw/inc/shellio.hxx b/sw/inc/shellio.hxx
index 14eaf0e..d915bb2 100644
--- a/sw/inc/shellio.hxx
+++ b/sw/inc/shellio.hxx
@@ -369,9 +369,6 @@ public:
 
 // BEGIN source/filter/basflt/fltini.cxx
 
-extern void _InitFilter();
-extern void _FinitFilter();
-
 extern SwRead ReadAscii, /*ReadSwg, ReadSw3, */ReadHTML, ReadXML;
 
 SW_DLLPUBLIC SwRead SwGetReaderXML();
diff --git a/sw/inc/swdll.hxx b/sw/inc/swdll.hxx
index 868682e..154f670 100644
--- a/sw/inc/swdll.hxx
+++ b/sw/inc/swdll.hxx
@@ -31,6 +31,8 @@
 #include 
 #include 
 
+namespace sw { class Filters; }
+
 /**
  * This class is a wrapper for a Load-On-Demand-DLL. One instance
  * per SfxApplication will be created for the runtime of
@@ -39,6 +41,8 @@
 namespace SwGlobals
 {
 void ensure();
+
+sw::Filters & getFilters();
 }
 
 #endif
diff --git a/sw/source/filter/basflt/fltini.cxx 
b/sw/source/filter/basflt/fltini.cxx
index 7f83ff1..a7bfa29 100644
--- a/sw/source/filter/basflt/fltini.cxx
+++ b/sw/source/filter/basflt/fltini.cxx
@@ -54,6 +54,7 @@
 #include 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -134,7 +135,15 @@ inline void _SetFltPtr( sal_uInt16 rPos, SwRead pReader )
 aReaderWriter[ rPos ].pReader = pReader;
 }
 
-void _InitFilter()
+namespace {
+
+extern "C" { static void SAL_CALL thisModule() {} }
+
+}
+
+namespace sw {
+
+Filters::Filters()
 {
 _SetFltPtr( READER_WRITER_BAS, (ReadAscii = new AsciiReader) );
 _SetFltPtr( READER_WRITER_HTML, (ReadHTML = new HTMLReader) );
@@ -144,7 +153,7 @@ void _InitFilter()
 _SetFltPtr( READER_WRITER_TEXT, ReadAscii );
 }
 
-void _FinitFilter()
+Filters::~Filters()
 {
 // die Reader vernichten
 for( sal_uInt16 n = 0; n < MAXFILTER; ++n )
@@ -155,6 +164,17 @@ void _FinitFilter()
 }
 }
 
+oslGenericFunction Filters::GetMswordLibSymbol( const char *pSymbol )
+{
+static ::rtl::OUString aLibName( RTL_CONSTASCII_USTRINGPARAM( SVLIBRARY( 
"msword" ) ) );
+if (!msword_.is())
+SvLibrary::LoadModule( msword_, aLibName, &thisModule, 
SAL_LOADMODULE_GLOBAL | SAL_LOADMODULE_LAZY );
+if (msword_.is())
+return msword_.getFunctionSymbol( ::rtl::OUString::createFromAscii( 
pSymbol ) );
+return NULL;
+}
+
+}
 
 namespace SwReaderWriter {
 
@@ -807,23 +827,9 @@ void SwAsciiOptions::WriteUserData( String& rStr )
 rStr += ',';
 }
 
-extern "C" { static void SAL_CALL thisModule() {} }
-
-static oslGenericFunction GetMswordLibSymbol( const char *pSymbol )
-{
-static ::osl::Module aModule;
-static sal_Bool bLoaded = sal_False;
-static ::rtl::OUString aLibName( RTL_CONSTASCII_USTRINGPARAM( SVLIBRARY( 
"msword" ) ) );
-if (!bLoaded)
-bLoaded = SvLibrary::LoadModule( aModule, aLibName, &thisModule, 
SAL_LOADMODULE_GLOBAL | SAL_LOADMODULE_LAZY );
-if (bLoaded)
-return aModule.getFunctionSymbol( ::rtl::OUString::createFromAscii( 
pSymbol ) );
-return NULL;
-}
-
 Reader* GetRTFReader()
 {
-FnGetReader pFunction = reinterpret_cast( GetMswordLibSymbol( 
"ImportRTF" ) );
+FnGetReader pFunction = reinterpret_cast( 
SwGlobals::getFilters().GetMswordLibSymbol( "ImportRTF" ) );
 
 if ( pFunction )
 return (*pFunction)();
@@ -833,7 +839,7 @@ Reader* GetRTFReader()
 
 void GetRTFWriter( const String& rFltName, const String& rBaseURL, WriterRef& 
xRet )
 {
-FnGetWriter pFunction = reinterpret_cast( GetMsword

[Libreoffice-commits] .: 3 commits - basic/inc basic/source

2011-10-06 Thread Tor Lillqvist
 basic/inc/basic/basicrt.hxx   |8 
 basic/source/sbx/sbxcurr.cxx  |9 +
 basic/source/sbx/sbxvalue.cxx |7 +++
 3 files changed, 20 insertions(+), 4 deletions(-)

New commits:
commit 8529da08517b41bd9317714e3216bb6d487b24ee
Author: Tor Lillqvist 
Date:   Thu Oct 6 10:12:47 2011 +0300

WaE: unreachable code

diff --git a/basic/source/sbx/sbxvalue.cxx b/basic/source/sbx/sbxvalue.cxx
index 8b55561..7ca1d9c 100644
--- a/basic/source/sbx/sbxvalue.cxx
+++ b/basic/source/sbx/sbxvalue.cxx
@@ -1311,9 +1311,16 @@ Lbl_OpIsDouble:
 else aL.nDouble /= aR.nDouble; break;
 case SbxPLUS:
 aL.nDouble += aR.nDouble; break;
+#if 0
+// See 'break' on preceding line... this
+// is unreachable code. Do not delete this
+// #if 0 block unless you know for sure
+// the 'break' above is intentional.
+
 // #45465 Date needs with "+" a special handling: 
forces date type
 if( GetType() == SbxDATE || rOp.GetType() == 
SbxDATE )
 aL.eType = SbxDATE;
+#endif
 case SbxMINUS:
 aL.nDouble -= aR.nDouble; break;
 case SbxNEG:
commit ba491984f49ca29bcfe0515145bcef0c12189270
Author: Tor Lillqvist 
Date:   Thu Oct 6 10:08:06 2011 +0300

WaE: inconsistent dll linkage

basicrt goes into the static app library, so DLL import/export
decorations meaningless.

diff --git a/basic/inc/basic/basicrt.hxx b/basic/inc/basic/basicrt.hxx
index 981fe18..4e6b4de 100644
--- a/basic/inc/basic/basicrt.hxx
+++ b/basic/inc/basic/basicrt.hxx
@@ -40,9 +40,9 @@ class BasicRuntime
 SbiRuntime* pRun;
 public:
 BasicRuntime( SbiRuntime* p ) : pRun ( p ){;}
-BASIC_DLLPUBLIC const String GetSourceRevision();
-BASIC_DLLPUBLIC const String GetModuleName( SbxNameType nType );
-BASIC_DLLPUBLIC const String GetMethodName( SbxNameType nType );
+const String GetSourceRevision();
+const String GetModuleName( SbxNameType nType );
+const String GetMethodName( SbxNameType nType );
 xub_StrLen GetLine();
 xub_StrLen GetCol1();
 xub_StrLen GetCol2();
@@ -64,7 +64,7 @@ public:
 xub_StrLen GetCol2();
 };
 
-class BASIC_DLLPUBLIC BasicRuntimeAccess
+class BasicRuntimeAccess
 {
 public:
 static BasicRuntime GetRuntime();
commit cce8278ebaf333024b867d9b68d3feb70235f1dc
Author: Tor Lillqvist 
Date:   Thu Oct 6 09:36:07 2011 +0300

WaE: unreachable code

diff --git a/basic/source/sbx/sbxcurr.cxx b/basic/source/sbx/sbxcurr.cxx
index 574c804..c227681 100644
--- a/basic/source/sbx/sbxcurr.cxx
+++ b/basic/source/sbx/sbxcurr.cxx
@@ -268,13 +268,21 @@ start:
 case SbxSALINT64:
 {
 nRes = p->nInt64 * CURRENCY_FACTOR; break;
+#if 0
+// Huh, is the 'break' above intentional? That means this
+// is unreachable, obviously. Avoid warning by ifdeffing
+// this out for now. Do not delete this #if 0 block unless
+// you know for sure the 'break' above is intentional.
 if ( nRes > SbxMAXSALINT64 )
 {
 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMAXSALINT64;
 }
+#endif
 }
 case SbxSALUINT64:
 nRes = p->nInt64 * CURRENCY_FACTOR; break;
+#if 0
+// As above
 if ( nRes > SbxMAXSALINT64 )
 {
 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMAXSALINT64;
@@ -284,6 +292,7 @@ start:
 SbxBase::SetError( SbxERR_OVERFLOW ); nRes = SbxMINSALINT64;
 }
 break;
+#endif
 //TODO: bring back SbxINT64 types here for limits -1 with flag value at 
SAL_MAX/MIN
 case SbxSINGLE:
 if( p->nSingle * CURRENCY_FACTOR + 0.5 > (float)SAL_MAX_INT64
___
Libreoffice-commits mailing list
Libreoffice-commits@lists.freedesktop.org
http://lists.freedesktop.org/mailman/listinfo/libreoffice-commits
diff --git a/shell/source/unix/exec/shellexec.cxx 
b/shell/source/unix/exec/shellexec.cxx
index 4af7c7b..40a2fa3 100644
--- a/shell/source/unix/exec/shellexec.cxx
+++ b/shell/source/unix/exec/shellexec.cxx
@@ -159,7 +159,7 @@ void SAL_CALL ShellExec::execute( const OUString& aCommand, 
const OUString& aPar
 #ifdef MACOSX
 aBuffer.append("open");
 #else
 // The url launchers are expected to be in the $OOO_BASE_DIR/program
 // directory:
 com::sun::star::uno::Reference< com::sun::star::util::XMacroExpander >
 exp;
@@ -182,11 +182,11 @@ void SAL_CALL ShellExec::execute( const OUString& 
aCommand, const OUString& aPar
 try {
 aProgramURL = exp->expandMacros(
 rtl::OUString(
-RTL_CONSTASCII_USTRINGPARAM("$OOO_BASE_DIR/program/")));
+RTL_CONSTASCII_USTRINGPARAM("$BRAND_BASE_DIR/program/")));
 } catch (com::sun::star::lang::IllegalArgumentException &)
 {
 throw SystemShellExecuteException(
-OUString(RTL_CONSTASCII_USTRINGPARAM("Could not expand 
$OOO_BASE_DIR path")),
+OUString(RTL_CONSTASCII_USTRINGPARAM("Could not expand 
$BRAND_BASE_DIR path")),
 static_cast < XSystemShellExecute * > (this), ENOENT );
 }
@@ -159,7 +159,7 @@ void SAL_CALL ShellExec::execute( const OUString& aCommand, 
 aBuffer.append("open");
 #else
-// The url launchers are expected to be in the $OOO_BASE_DIR/program
+// The url launchers are expected to be in the $BRAND_BASE_DIR/program
 // directory:
 com::sun::star::uno::Reference< com::sun::star::util::XMacroExpander >
 